#!/bin/bash -e

rep=report
doc=storred_doc

. env.sh

rm -fr ${rep}
rm -f ${doc}

open_after 0.5 &

p0=0.0
p1=0.0

ti=0.0
ti=1.0

set -x
ln -s ${pyexe} ./python_link

./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/molrep_mr2.log -c molrep
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/7_aimless.log -s
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/10_refmac5.log -t
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/warpNtrace.log -k Examples/warpNtrace.inp -c arpwarp
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/buccaneerpipeline_stdout.txt -s
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/10_phaser_MR.log
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/refmac.log
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/molrep_cofe.log -c molrep
#sleep ${ti}
#./python_link demo.py -d ${doc} -p ${p1} -v Examples/ccpem.log
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/64_mr_mrf.log -c molrep
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/65_mr_saptf_prf.log -c molrep
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/66_mr_saptf_lrf.log -c molrep
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/10_refmac5.log -t -n
sleep ${ti}
./python_link demo.py -d ${doc} -p ${p1} -v -e Examples/7_aimless.log -s -n
sleep ${ti}
if test -f Examples/cofe_acorn.log; then
  ./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/cofe_acorn.log -s
  sleep ${ti}
fi
skip() {
  ./python_link demo.py -d ${doc} -p ${p0} -v -e Examples/18.11.27_stdout.log
  sleep ${ti}
}
./python_link demo.py -d ${doc} -p ${p1} -v Examples/19.11.29_phaser_stdout.log
sleep ${ti}
./python_link demo.py /dev/null

rm -f ./python_link
set +x

rm -f ${doc}

sed -i.bak 's/^TASK_STAMP.*/TASK_STAMP:::1536675447:::39238:::PASS;;;/' ${rep}/task.tsk
rm ${rep}/task.tsk.bak

